0.9.9 API documentation: quaternion_relational.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

quaternion_relational.hpp
Go to the documentation of this file.
1
17 #pragma once
18
19 // Dependency:
20 #include "../vector_relational.hpp"
21
22 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
23 # pragma message("GLM: GLM_EXT_quaternion_relational extension included")
24 #endif
25
26 namespace glm
27 {
30
35 template<typename T, qualifier Q>
36 GLM_FUNC_DECL vec<4, bool, Q> equal(qua<T, Q> const& x, qua<T, Q> const& y);
37
42 template<typename T, qualifier Q>
43 GLM_FUNC_DECL vec<4, bool, Q> equal(qua<T, Q> const& x, qua<T, Q> const& y, T epsilon);
44
49 template<typename T, qualifier Q>
50 GLM_FUNC_DECL vec<4, bool, Q> notEqual(qua<T, Q> const& x, qua<T, Q> const& y);
51
56 template<typename T, qualifier Q>
57 GLM_FUNC_DECL vec<4, bool, Q> notEqual(qua<T, Q> const& x, qua<T, Q> const& y, T epsilon);
58
60 } //namespace glm
61
62 #include "quaternion_relational.inl"
glm::epsilon
GLM_FUNC_DECL GLM_CONSTEXPR genType epsilon()
Return the epsilon constant for floating point types.
glm::notEqual
GLM_FUNC_DECL vec< 4, bool, Q > notEqual(qua< T, Q > const &x, qua< T, Q > const &y, T epsilon)
Returns the component-wise comparison of |x - y| >= epsilon.
glm::equal
GLM_FUNC_DECL vec< 4, bool, Q > equal(qua< T, Q > const &x, qua< T, Q > const &y, T epsilon)
Returns the component-wise comparison of |x - y| < epsilon.
glm
Definition: common.hpp:20